# frozen_string_literal: true

require "json"
require "fileutils"
require_relative "./config_manager"

class EnvironmentBuilder
  attr_accessor :configs

  def initialize
    @config_manager = ConfigManager.new
    @configs = {}
    @env = "dev"
  end

  def create_environment(name, silent: false)
    unless silent
      puts "Hi, I am ApiBot!"
      print "You can have multiple environments of API requests and easily switch between them. "
      puts "To create an environment please follow the steps,\n"
      puts "Note: I have created some default values for easily getting started."
      puts "Press enter for using default value."
    end

    @configs = @config_manager.get_all if File.exist?(Global::ENV_FILE_PATH)
    set_environment name
    get_base_url
    get_auth_token_header_key
    get_auth_token_header_value
    save_config_as_json
  end

  def list_environments
    @config_manager.get_all
  end

  def get_environment(name:)
    @config_manager.get_by_env(env: name)
  end

  def delete_environment(name)
    environments = @config_manager.get_all
    environments.delete(name)
    @config_manager.save environments
  end

  private

  def set_environment(name)
    env = name
    @env = env unless env.empty?
    @configs[@env] = {} unless @configs.key?(@env)
    @configs[@env]["requests"] = {}
  end

  def get_base_url
    puts "Enter the Base URL: ['']"
    env = $stdin.gets.chomp
    @configs[@env]["base_url"] = env.empty? ? "" : env
  end

  def get_auth_token_header_key
    puts "Enter the authorization token header key: [Authorization]"
    env = $stdin.gets.chomp
    @configs[@env]["token_key"] = env.empty? ? "Authorization" : env
  end

  def get_auth_token_header_value
    puts "Enter the authorization token header value. Eg., Bearer asda23245tfasd: ['']"
    env = $stdin.gets.chomp
    @configs[@env]["token_value"] = env.empty? ? "" : env
  end

  def save_config_as_json
    @config_manager.save(@configs)
  end
end
