require "json"
require "fileutils"
require_relative "./global"
require_relative "./config_manager"

class RequestBuilder
  def initialize(name: "", env: "dev")
    @env = env
    @name = name
    @endpoint = ""
    @headers = {}
    @method = "get"
    @body = {}
    @request = {}
    @config_manager = ConfigManager.new
  end

  def create_request
    get_endpoint
    get_headers
    get_method
    get_body
    self
  end

  def get_all
    @config_manager.get_all[@env]["requests"]
  end

  def get_by_name(name)
    @config_manager.get_all[@env]["requests"][name]
  end

  def save
    configs = @config_manager.get_all
    if configs.nil? || configs == {}
      puts "Error: No Environments detected."
      puts "Please run 'cadburybot env set <env-name>' command to create a new environment"
      exit
    end
    configs[@env]["requests"][@name] = build_request
    @config_manager.save configs
  end

  private

  def get_endpoint
    puts "Endpoint: eg., /api/check-weather"
    @endpoint = $stdin.gets.chomp
  end

  def get_headers
    loop do
      puts "Headers: [headerKey:headerValue] ---> Type value or press <Enter> to skip"
      key, value = $stdin.gets.chomp.split ":"
      break if key.nil? || value.nil?

      @headers[key] = value
    end
  rescue StandardError => e
    puts "Error: #{e.message}"
    exit
  end

  def get_method
    puts "Method: [GET]"
    @method = $stdin.gets.chomp.upcase
  end

  def get_body
    puts "Body: []"
    body = $stdin.gets.chomp
    @body = JSON.parse body unless body.empty?
  end

  def build_request
    {
      method: @method,
      headers: @headers,
      body: @body
    }
  end
end
